@@ -16,9 +16,8 @@ def update_context(app, pagename, templatename, context, doctree):
 
 
 def setup(app):
-    # add_html_theme is new in Sphinx 1.6+
-    if hasattr(app, "add_html_theme"):
-        theme_path = os.path.abspath(os.path.dirname(__file__))
-        app.add_html_theme("alabaster", theme_path)
+    app.require_sphinx("1.6")
+    theme_path = os.path.abspath(os.path.dirname(__file__))
+    app.add_html_theme("alabaster", theme_path)
     app.connect("html-page-context", update_context)
     return {"version": version.__version__, "parallel_read_safe": True}
